# pylint: disable = import-error
import bpy
from .main import main
from .constants import UNBREAKABLE_CONSTRAINTS, BREAKABLE_CONSTRAINTS

class OBJECT_OT_rigid_body_connector(bpy.types.Operator):
    """Tooltip"""
    bl_idname = "object.rigid_body_connector"
    bl_label = "Rigid Body Connector"
    bl_description = "Add rigid body constrainst to selected objects"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {'REGISTER' , 'UNDO'}

    @classmethod
    def poll(cls, context):
        try:
            return len(context.scene.rigidbody_world.collection.objects) > 1
        except:
            pass

    def execute(self, context):

        props = context.scene.RigidBodyConnectorProps

        main(context, props)
        return {'FINISHED'}

class OBJECT_OT_reset_constraints(bpy.types.Operator):
    """Tooltip"""
    bl_idname = "object.reset_constraints"
    bl_label = "Reset Constraints"
    bl_description = "Reset constrainsts created by Rigid Body Connect"
    bl_space_type = "VIEW_3D"
    bl_region_type = "UI"
    bl_options = {'REGISTER' , 'UNDO'}



    @classmethod
    def poll(cls, context):
        try:
            constraints = context.scene.rigidbody_world.constraints.objects
            if(constraints):
                return len(context.scene.rigidbody_world.constraints.objects) >= 1 # this should only opertate if existing constrainst
        except:
            pass

    def execute(self,context):
        try:
            props = context.scene.RigidBodyConnectorProps
            makeBreakable = props.MakeBreakable
            if(makeBreakable):
                for obj in bpy.data.collections[BREAKABLE_CONSTRAINTS].objects:
                    obj.rigid_body_constraint.object1.color = (1,1,1,1)
                    obj.rigid_body_constraint.object2.color = (1,1,1,1)
                    bpy.data.objects.remove (
                        object = obj,
                        do_unlink = True,
                        do_id_user = True,
                        do_ui_user = True
                        )
            if(not makeBreakable):
                for obj in  bpy.data.collections[UNBREAKABLE_CONSTRAINTS].objects:
                    obj.rigid_body_constraint.object1.color = (1,1,1,1)
                    obj.rigid_body_constraint.object2.color = (1,1,1,1)
                    bpy.data.objects.remove (
                    object = obj,
                    do_unlink = True,
                    do_id_user = True,
                    do_ui_user = True
                    )          
        except:
            pass

        return {'FINISHED'}